## ========================================================================== ##
## Public Replication File for:
##   
##   Alan S. Gerber, Gregory A. Huber, and Albert H. Fang
## 
## "Do Subtle Linguistic Interventions Priming a Social Identity
## as a Voter Have Outsized Effets on Voter Turnout? Evidence
## From a New Replication Experiment"
## 
## Political Psychology. doi: 10.1111/pops.12446
## 
## Last updated: 26 September 2017
##
## -------------------------------------------------------------------------- ##
##
## PROGRAM DESCRIPTION:
## This program implements the procedure detailed in Appendix E to back out
## 95% confidence intervals for effect estimates from Bryan et al. (2011)
## that are presented in Figure 1
##
## ========================================================================== ##

rm(list=ls(all=TRUE))

##==========================================##
## Bryan et al (2011), Study 2
##==========================================##

## Total N = 88
## Assume balanced design, so 44 verb, 44 noun
88/2
## How many voted in each group?
## Look for proportions equal to 95.5 (noun) and 81.8 (verb)
cbind(1:44, (1:44)/44)

# 42 of 44 approx= 95.45% (noun)
# 36 of 44 approx= 81.8% (verb)

# Z-test of diff in proportions, two-sided test, p value = 0.093
prop.test(x=c(42,36), n=c(44,44), alternative="two.sided")$p.value

# Regression framework, p value = 0.044
s2_data <- data.frame(noun_treat = c(rep(1,44), rep(0,44)),
                      vote = c( rep(1,42), rep(0,44-42), rep(1,36), rep(0, 44-36) ) )

summary(lm(vote ~ noun_treat, data=s2_data))


##==========================================##
## Bryan et al (2011), Study 3
##==========================================##

## Total N = 216
## Assume balanced design, so 108 verb, 108 noun
214/2
## How many voted in each group?
## Look for proportions equal to 89.9 (noun) and 79 (verb)
cbind(1:107, (1:107)/107)

# 96 of 107 approx= 89.8% (noun)
# 85 of 107 approx= 79% (verb)

# Z-test of diff in proportions, two-sided test, p value = 0.04
prop.test(x=c(96,85), n=c(107,107), alternative="two.sided")$p.value

# Regression framework, p value = 0.025
s3_data <- data.frame(noun_treat = c(rep(1,107), rep(0,107)),
                      vote = c( rep(1,96), rep(0,107-96), rep(1,85), rep(0, 107-85) ) )

summary(lm(vote ~ noun_treat, data=s3_data))


